import router from "./router";
import store from "./store";
import { Message } from "element-ui";
import NProgress from "nprogress";
import "nprogress/nprogress.css";
import { getToken } from "@/utils/auth";
import { isRelogin } from "@/utils/request";
import { getBaseUrl } from "@/utils/baseUrl.js";
NProgress.configure({ showSpinner: false });

const whiteList = ["/login", "/register", "/postcheck"];

router.beforeEach((to, from, next) => {
  NProgress.start();
  if (getToken()) {
    to.meta.title && store.dispatch("settings/setTitle", to.meta.title);
    /* has token*/
    if (to.path === "/login") {
      next({ path: "/login" });
      NProgress.done();
    } else if (whiteList.indexOf(to.path) !== -1) {
      next();
    } else {
      if (store.getters.roles.length === 0) {
        isRelogin.show = true;
        // 判断当前用户是否已拉取完user_info信息
        store
          .dispatch("GetInfo")
          .then(() => {
            isRelogin.show = false;
            store.dispatch("GenerateRoutes").then((accessRoutes) => {
              // 根据roles权限生成可访问的路由表
              router.addRoutes(accessRoutes); // 动态添加可访问路由表
              next({ ...to, replace: true }); // hack方法 确保addRoutes已完成
            });
          })
          .catch((err) => {
            store.dispatch("LogOut").then(() => {
              Message.error(err);
              const type = window.localStorage.getItem("isPathType");
              if (type == 2) {
                next({ path: "/login" });
              } else {
                location.href = `http://10.152.70.21:8080/cas/logout?service=${getBaseUrl()}/redirectpostcheck`;
              }
            });
          });
      } else {
        next();
      }
    }
  } else {
    if (whiteList.indexOf(to.path) === -1) {
      // 存没有登录地址
      window.localStorage.setItem("redirect", to.path);
    }
    // 没有token
    if (whiteList.indexOf(to.path) !== -1) {
      // 在免登录白名单，直接进入
      next();
    } else {
      // 否则全部重定向到登录页
      if (to.path === "/login") {
        // 普通登录
        next(`/login?redirect=${encodeURIComponent(to.fullPath)}`);
        NProgress.done();
        return;
      }
      // cas认证登录
      next("/postcheck");
      NProgress.done();
    }
  }
});

router.afterEach(() => {
  NProgress.done();
});
